# Contributing to NodeConductor

NodeConductor is an open project welcoming contributions. To assure the
smooth acceptance of contributions please review the contribution guidelines below.

## Pull requests

We welcome contributions (patches, new features, translations, etc) through pull requests.
Please make sure that the following is addressed when making a pull request:

- a request has a clear scope - new feature, bugfix, refactoring. Granular pull requests make integration much faster;
- the code is following pep8 code conventions;

## License
By contributing your code, you agree to license your contribution under the [MIT license](LICENSE.md).
